@@ -93,7 +93,6 @@ struct AudioView {
 	gulong seek_changed_id;
 	gdouble last_seek_value; /* so we can see if we changed the slider
 				    or the user */
-	GList *audio_list;
 	AudioPlay *audio_play;
 	gboolean scanning;
 	guint scan_timeout;
@@ -108,6 +107,7 @@ struct AudioView {
 	GstMediaInfoStream *stream;	/* set by idler read */
 	GList *audio_item;	/* pointer to current audio_list item under
 				   inspection */
+        GList *audio_list;
 	GtkTreeIter *iterp;
 };
 
@@ -155,8 +155,11 @@ control_box_add_labeled_button (GtkWidget *control,
 	GtkWidget *button;
 	GdkPixbuf *pixbuf;
 	GtkWidget *image;
+	GtkTooltips *button_bar_tips;
 	gchar *location;
-
+	
+	button_bar_tips = gtk_tooltips_new ();
+	
 	if (toggle)
 	{
 		button = gtk_toggle_button_new ();
@@ -178,35 +181,48 @@ control_box_add_labeled_button (GtkWidget *control,
 		gtk_container_add (GTK_CONTAINER (button),
 				   gtk_label_new (label));
 	gtk_box_pack_start (GTK_BOX (control), button, FALSE, FALSE, 0);
-
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (button_bar_tips), button,
+				 label,
+				 label);
+	
 	return button;
 }
 
-/* check if the uri is playable and return the mime type if it is, NULL
- * if not */
-char *
+/* check if the uri is playable
+ * return TRUE if it is, FALSE if not
+ */
+gboolean
 audio_view_is_playable (const char *uri)
 {
         char *type = NULL;
 
+        /* we get a newly allocated type with this function */
+        /* FIXME: why do we need this cast ? it ought to return char * ! */
         type = (char *) gnome_vfs_get_mime_type (uri);
-        /* FIXME: assuming we get an allocated copy and have ownership */
-        if (!type) return NULL;
+        if (!type) return FALSE;
+        /* We also check for "old" mime types to catch everything */
         if (
-            (strcmp (type, "application/x-ogg") != 0) &&
+            /* gnome-vfs mime types */
+            (strcmp (type, "application/ogg") != 0) &&
+            (strcmp (type, "application/x-flac") != 0) &&
             (strcmp (type, "audio/x-flac") != 0) &&
+            (strcmp (type, "audio/mpeg") != 0) &&
             (strcmp (type, "audio/x-mp3") != 0) &&
+            (strcmp (type, "audio/mpeg") != 0) &&
             (strcmp (type, "audio/x-wav") != 0) &&
 	    (strcmp (type, "audio/x-mod") != 0) &&
 	    (strcmp (type, "audio/x-s3m") != 0) &&
 	    (strcmp (type, "audio/x-xm") != 0) &&
-	    (strcmp (type, "audio/x-it") != 0)
+	    (strcmp (type, "audio/x-it") != 0) &&
+            /* legacy mime types */
+            (strcmp (type, "application/x-ogg") != 0)
 	   )
         {
                 g_free (type);
-                return NULL;
+                return FALSE;
         }
-        return type;
+        g_free (type);
+        return TRUE;
 }
 
 /* extract GList of string properties to a string of different lines
@@ -249,11 +265,13 @@ static gchar *
 audio_view_mime_to_type (const gchar *mime)
 {
 	gchar *result;
-        if (strcmp (mime, "application/x-ogg") == 0)
+        if ((strcmp (mime, "application/x-ogg") == 0) ||
+            (strcmp (mime, "application/ogg") == 0))
 		return g_strdup (_("Ogg/Vorbis"));
         if (strcmp (mime, "application/x-flac") == 0)
 		return g_strdup (_("FLAC"));
-        if (strcmp (mime, "audio/x-mp3") == 0)
+        if ((strcmp (mime, "audio/x-mp3") == 0) ||
+            (strcmp (mime, "audio/mpeg") == 0))
 		return g_strdup (_("MPEG"));
         if (strcmp (mime, "audio/x-wav") == 0)
 		return g_strdup (_("WAVE"));
@@ -276,7 +294,8 @@ audio_view_mime_to_type (const gchar *mime)
 	return g_strdup (_("Unknown"));
 }
 
-/* extract the useful metadata to an allocated string */
+/* extract the useful metadata to an allocated string
+   returns Unknown if no useful metadata could be found */
 static gchar *
 audio_view_media_get_metadata (GstMediaInfoStream *info)
 {
@@ -300,6 +319,9 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 
 	p = track->metadata->properties->properties;
 
+        if (!p) /* no metadata */
+                return g_strdup (_("Unknown"));
+
 	/* construct GLists of GstPropsEntries to artist and title */
 	while (p)
 	{
@@ -319,6 +341,8 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 		p = g_list_next (p);
 	}
 
+        /* check if we have something */
+        if (!artist && !title) return NULL; //g_strdup ("");
 	/* now construct a string out of it */
 	artists = audio_view_props_to_string (artist, _("Artist: "));
 	titles = audio_view_props_to_string (title, _("Title: "));
@@ -622,7 +646,7 @@ play_activate (GtkButton *play_button, AudioView *view)
 	}
 	else
 	{
-		message = g_strdup_printf (_("Make a selection first!"));
+		message = g_strdup_printf (_("Make a selection first !"));
 		gtk_label_set_text (GTK_LABEL (view->status), message);
 		g_free (message);
 	}
@@ -755,6 +779,18 @@ audio_view_media_info_next (AudioView *view)
 	return FALSE;
 }
 
+static void
+free_iter_list (GList *list)
+{
+	GList *l;
+
+	for (l = list; l != NULL; l = l->next) {
+		gtk_tree_iter_free (l->data);
+	}
+
+	g_list_free (list);
+}
+
 static gboolean
 audio_view_get_media_info_idler (AudioView *view)
 {
@@ -795,6 +831,8 @@ audio_view_get_media_info_idler (AudioView *view)
 			g_free (escaped_name);
 			NM_DEBUG("getting media-info for path uri %s\n",
 			         path_uri);
+                        if (view->media_info == NULL)
+                        	return FALSE;
 			gst_media_info_read_with_idler (view->media_info,
 							path_uri,
 							GST_MEDIA_INFO_ALL);
@@ -815,7 +853,7 @@ audio_view_get_media_info_idler (AudioView *view)
 				if (!gst_media_info_read_idler (view->media_info,
 								&(view->stream)))
 				{
-						g_warning ("error on media info idler !");
+						g_print ("WARNING: error on media info idler !");
 						/* FIXME: better cleanup here */
 						audio_view_media_info_next (view);
 				}
@@ -916,6 +954,8 @@ audio_view_update (AudioView *view)
 	 * and FIXME: extracting media-info data if present */
         /* populate the list with filenames */
         gtk_list_store_clear (view->list_store);
+        free_iter_list (view->audio_list);
+        view->audio_list = NULL;
 	for (node = list; node != NULL; node = node->next) {
 		current_file_info = node->data;
 
@@ -1213,9 +1253,12 @@ audio_view_dispose (AudioView *view)
 	}
 
 	if (view->media_info_idler_id) {
+                g_print("removing media info idler");
 		g_source_remove (view->media_info_idler_id);
 		view->media_info_idler_id = 0;
 	}
+        else
+                g_print("media info idler already removed");
 
 	if (view->scan_timeout) {
 		g_source_remove (view->scan_timeout);
@@ -1233,18 +1276,6 @@ audio_view_dispose (AudioView *view)
 	}
 }
 
-static void
-free_iter_list (GList *list)
-{
-	GList *l;
-	
-	for (l = list; l != NULL; l = l->next) {
-		gtk_tree_iter_free (l->data);
-	}
-
-	g_list_free (list);
-}
-
 void
 audio_view_finalize (AudioView *view)
 {
