@@ -258,6 +258,9 @@ gst_media_info_read_with_idler (GstMediaInfo *info, const char *location,
 gboolean
 gst_media_info_read_idler (GstMediaInfo *info, GstMediaInfoStream **streamp)
 {
+  /* if it's NULL then we're sure something went wrong higher up) */
+  if (info == NULL) return FALSE;
+
   GstMediaInfoPriv *priv = info->priv;
 
   g_assert (streamp != NULL);
@@ -291,7 +294,12 @@ gst_media_info_read_idler (GstMediaInfo *info, GstMediaInfoStream **streamp)
       mime = g_strdup (gst_caps_get_mime (priv->type));
       GMI_DEBUG("found out mime type: %s\n", mime);
       decoder = gmi_get_decoder (info, mime);
-      if (decoder == NULL) return FALSE;
+      if (decoder == NULL)
+      {
+        /* FIXME: pop up error */
+        GMI_DEBUG("DEBUG: no decoder found for mime %s\n", mime);
+        return FALSE;
+      }
       priv->stream = gmi_stream_new ();
       GMI_DEBUG("DEBUG: new stream: %p\n", priv->stream);
       priv->stream->mime = mime;
@@ -332,7 +340,7 @@ gst_media_info_read_idler (GstMediaInfo *info, GstMediaInfoStream **streamp)
         return TRUE;
       }
       if (priv->metadata_iters == MAX_METADATA_ITERS)
-	      g_warning ("iterated a few times, didn't find metadata");
+	      g_print ("iterated a few times, didn't find metadata\n");
       if (priv->metadata == NULL)
       {
 	/* this is not a permanent failure */
@@ -357,7 +365,8 @@ gst_media_info_read_idler (GstMediaInfo *info, GstMediaInfoStream **streamp)
 	/* this is not a permanent failure */
         GMI_DEBUG("Couldn't find streaminfo\n");
       }
-      GMI_DEBUG("found streaminfo of track %d\n", priv->current_track_num);
+      else
+        GMI_DEBUG("found streaminfo of track %d\n", priv->current_track_num);
       if (!gmip_find_track_streaminfo_post (priv)) return FALSE;
       priv->state = GST_MEDIA_INFO_STATE_FORMAT;
       return gmip_find_track_format_pre (priv);
@@ -436,6 +445,7 @@ gst_media_info_read (GstMediaInfo *info, const char *location, guint16 flags)
 
   /* c) figure out decoder */
   decoder = gmi_get_decoder (info, mime);
+  g_print ("DEBUG: using decoder %s\n", gst_element_get_name (decoder));
 
  /* if it's NULL, then that's a sign we can't decode it */
   if (decoder == NULL)
